==> xmule-1.9.0.tar.bz2: xmule-1.9.0/src/CommentDialogLst.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef COMMENTDLGLIST_H
#define COMMENTDLGLIST_H

#include <wx/dialog.h>                  // Needed for wxDialog
#include <wx/listctrl.h>                // Needed for wxListCtrl

#include "resource.h"                   // Needed for IDS_CD_UNAME
#include "wintypes.h"                   // Needed for BOOL

class CPartFile;

// CCommentDialogLst dialog 

class CCommentDialogLst : public wxDialog
{ 
  //DECLARE_DYNAMIC(CCommentDialogLst) 

public: 
   CCommentDialogLst(wxWindow* pParent,CPartFile* file); 
   virtual ~CCommentDialogLst(); 
   void Localize(); 
   virtual BOOL OnInitDialog(); 
   //CHyperTextCtrl lstbox; 
   wxListCtrl *pmyListCtrl;

// Dialog Data 
    enum
    {
        IDD_COMMENTLST, 
        IDD = IDD_COMMENTLST
    }; 
protected: 
   //virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support 
   //DECLARE_MESSAGE_MAP() 
   DECLARE_EVENT_TABLE()
public: 
   void OnBnClickedApply(wxEvent& evt); 
   void OnBnClickedRefresh(wxEvent& evt); 
private: 
   void CompleteList(); 
   CPartFile* m_file; 
};

#endif

==> xmule-1.9.1b.tar.bz2: xmule-1.9.1b/src/CommentDialogLst.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef COMMENTDLGLIST_H
#define COMMENTDLGLIST_H

#include "resource.h"                       // Needed for IDS_CD_UNAME
#include "wintypes.h"                       // Needed for BOOL

#include <wx/dialog.h>                      // Needed for wxDialog

class CPartFile;
class wxListCtrl;

class CCommentDialogLst : public wxDialog
{
public:
   CCommentDialogLst(wxWindow* pParent,CPartFile* file);
   virtual ~CCommentDialogLst();
   void Localize();
   virtual BOOL OnInitDialog();
   wxListCtrl *pmyListCtrl;

// Dialog Data
    enum
    {
        IDD_COMMENTLST,
        IDD = IDD_COMMENTLST
    };
protected:
   DECLARE_EVENT_TABLE()
public:
   void OnBnClickedApply(wxCommandEvent& evt);
   void OnBnClickedRefresh(wxCommandEvent& evt);
private:
   void CompleteList();
   CPartFile* m_file;
};

#endif
